#define INT
#define INTLIT
#define FLOAT
#define FLOATLIT
#define STRING
#define STRINGLIT

#include "type.ml"

#include "monomorphic.mli"

#include "write.mli"

#include "write2.mli"

#undef INT
#undef INTLIT
#undef FLOAT
#undef FLOATLIT
#undef STRING
#undef STRINGLIT
